@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010_000;
 
-our $VERSION = '1.003';
+our $VERSION = '1.005';
 
 use Class::Accessor::Lite (
     new => 0,
@@ -30,8 +30,8 @@ sub new {
     state $rule = Data::Validator->new(
         host     => { isa => 'Str' },
         port     => { isa => 'Int', default => 8086 },
-        username => { isa => 'Str' },
-        password => { isa => 'Str' },
+        username => { isa => 'Str', optional => 1 },
+        password => { isa => 'Str', optional => 1 },
         database => { isa => 'Str' },
         ssl      => { isa => 'Bool', default => 0 },
 
@@ -496,10 +496,11 @@ sub _build_url {
     )->with('Method');
     my($self, $args) = $rule->validate(@_);
 
-    my $url = sprintf("%s://%s:%s@%s:%d%s",
+    my $url = sprintf("%s://%s%s:%d%s",
                       ($self->ssl ? 'https' : 'http'),
-                      $self->username,
-                      $self->{password},
+                      ($self->username and $self->{password})
+                          ? sprintf('%s:%s@', $self->username, $self->{password})
+                          : '',
                       $self->host,
                       $self->port,
                       $args->{path},
@@ -547,6 +548,18 @@ To install this module, run the following commands:
 
 =end readme
 
+=head1 CAUTION
+
+    The JSON write protocol is deprecated as of InfluxDB 0.9.1. It is
+    still present but it will be removed when InfluxDB 1.0 is
+    released. The line protocol is the primary write protocol for
+    InfluxDB 0.9.1+.
+
+This InfluxDB module can handle only JSON protocol.
+
+If you want to use line protocol, please use L<InfluxDB::LineProtocol> module.
+
+
 =head1 SYNOPSIS
 
     use InfluxDB;
